@@ -39,15 +39,14 @@ validate_evolution_contact_1 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"pas-id-4C1F87A700000000",
-			"Notizen\n123",
-			"Miscellaneous,Strategien,Strategies,Wartend,Time & Expenses,Competition,Key Customer,Geschenke,Gifts,Geburtstag,Ideen,Suppliers,Konkurrenz,Ideas,Jahrestag,VIP,Holiday,International,Favoriten,Heiße Kontakte,Favorites,Goals/Objectives,Geschäftlich,Urlaubskarten,Persönlich,Urlaub,Zeit und Ausgaben,Hot Contacts,Ziele/Zielsetzungen,Lieferanten,Phone Calls,Anrufe,Status,Waiting,Holiday Cards,Business,Allgemeines,Schlüssel-Kunde",
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			"2010-08-24 15:37:58", stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "pas-id-4C1F87A700000000",
+	                 "Notizen\n123",
+	                 "Miscellaneous,Strategien,Strategies,Wartend,Time & Expenses,Competition,Key Customer,Geschenke,Gifts,Geburtstag,Ideen,Suppliers,Konkurrenz,Ideas,Jahrestag,VIP,Holiday,International,Favoriten,Heiße Kontakte,Favorites,Goals/Objectives,Geschäftlich,Urlaubskarten,Persönlich,Urlaub,Zeit und Ausgaben,Hot Contacts,Ziele/Zielsetzungen,Lieferanten,Phone Calls,Anrufe,Status,Waiting,Holiday Cards,Business,Allgemeines,Schlüssel-Kunde",
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 "2010-08-24 15:37:58", stage);
 
 	/*
 	 * Name Fields
@@ -80,11 +79,11 @@ validate_evolution_contact_1 (const I_contact *icontact, gint stage)
 	 * Addresses
 	 */
 	assert_address_in_list(icontact->addresses, ICONTACT_ADDR_TYPE_HOME,
-			"P Adresse", "P Postfach", "P Stadt", "P Bundesstaat", "P Postleitzahl", "P Land");
+	                       "P Adresse", "P Postfach", "P Stadt", "P Bundesstaat", "P Postleitzahl", "P Land");
 	assert_address_in_list(icontact->addresses, ICONTACT_ADDR_TYPE_BUSINESS,
-			"G Adresse", "G Postfach", "G Stadt", "G Bundesstaat", "G Postleitzahl", "G Land");
+	                       "G Adresse", "G Postfach", "G Stadt", "G Bundesstaat", "G Postleitzahl", "G Land");
 	assert_address_in_list(icontact->addresses, ICONTACT_ADDR_TYPE_OTHER,
-			"W Adresse", "W Postfach", "W Stadt", "W Bundesstaat", "W Postleitzahl", "W Land");
+	                       "W Adresse", "W Postfach", "W Stadt", "W Bundesstaat", "W Postleitzahl", "W Land");
 	assert_list_length(icontact->addresses, 3);
 
 	/*
@@ -126,11 +125,10 @@ validate_evolution_contact_1 (const I_contact *icontact, gint stage)
 	/*
 	 * Attached Multimedia Files
 	 */
-	assert_binary_attachment_equal(
-			"./src/libekolabconv/test/resources/evolution/contact/contact_e1_photo.png",
-			"kolab-picture.png",
-			"image/png",
-			icontact->photo);
+	assert_binary_attachment_equal("./src/libekolabconv/test/resources/evolution/contact/contact_e1_photo.png",
+	                               "kolab-picture.png",
+	                               "image/png",
+	                               icontact->photo);
 
 	/*
 	 * Geolocation Fields
@@ -143,7 +141,7 @@ validate_evolution_contact_1 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:Video-Chat\r\nCALURI:Kalender\r\nX-MOZILLA-HTML:TRUE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 }
 
 
@@ -155,15 +153,14 @@ validate_evolution_contact_2 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"pas-id-4C73E9E900000000",
-			NULL,
-			NULL,
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			"2010-08-24 15:48:57", stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "pas-id-4C73E9E900000000",
+	                 NULL,
+	                 NULL,
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 "2010-08-24 15:48:57", stage);
 
 	/*
 	 * Name Fields
@@ -237,7 +234,7 @@ validate_evolution_contact_2 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:\r\nCALURI:\r\nX-MOZILLA-HTML:FALSE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 }
 
 void
@@ -248,15 +245,14 @@ validate_evolution_contact_3 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"pas-id-4C73EAF900000001",
-			NULL,
-			NULL,
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			"2010-08-24 16:01:39", stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "pas-id-4C73EAF900000001",
+	                 NULL,
+	                 NULL,
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 "2010-08-24 16:01:39", stage);
 
 	/*
 	 * Name Fields
@@ -342,7 +338,7 @@ validate_evolution_contact_3 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:\r\nCALURI:\r\nX-MOZILLA-HTML:FALSE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 }
 
 void
@@ -353,15 +349,14 @@ validate_evolution_contact_4 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"pas-id-4C73EB8400000002",
-			NULL,
-			NULL,
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			"2010-08-24 15:56:53", stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "pas-id-4C73EB8400000002",
+	                 NULL,
+	                 NULL,
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 "2010-08-24 15:56:53", stage);
 
 	/*
 	 * Name Fields
@@ -444,7 +439,7 @@ validate_evolution_contact_4 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:\r\nCALURI:\r\nX-MOZILLA-HTML:FALSE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 }
 
 void
@@ -455,29 +450,28 @@ validate_evolution_contact_5 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"pas-id-4CA9939100000000",
-			"Στην επιστήμη της βιολογίας, με τον όρο εξέλιξη εννοείται η αλλαγή στις"
-			" ιδιότητες ενός πληθυσμού οργανισμών στο πέρασμα του χρόνου, μεταξύ δια"
-			"φορετικών γενεών[1]. Αν και τέτοιου τύπου μεταβολές παρατηρούνται σε μι"
-			"κρή κλίμακα σε κάθε γενιά, μακροπρόθεσμα και αθροιστικά μπορούν να οδηγ"
-			"ήσουν σε σημαντικές διαφοροποιήσεις στις ιδιότητες ενός οργανισμού, ώστ"
-			"ε να οδηγήσουν τελικά στη δημιουργία νέων διακριτών ειδών (βλ. ειδογένε"
-			"ση). Εξελικτικές θεωρούνται ειδικά οι αλλαγές που κληροδοτούνται μέσω τ"
-			"ου γενετικού υλικού από γενιά σε γενιά, συνεπώς συνιστούν μια πληθυσμικ"
-			"ή διαδικασία και διακρίνονται από άλλες, όπως η οντογένεση, ή γενικά η "
-			"ανάπτυξη ενός οργανισμού ατομικά. Η εξέλιξη αποτελεί φαινόμενο που υλοπ"
-			"οιείται σταδιακά και σε μεγάλο βάθος χρόνου. Με λίγες εξαιρέσεις[2], απ"
-			"αιτείται το πέρασμα αρκετών γενεών για εξελικτικές αλλαγές μεγάλης κλίμ"
-			"ακας, όπως για παράδειγμα η εξέλιξη των πτηνών από τα ερπετά. Λαμβάνει "
-			"επίσης χώρα με διαφορετικούς ρυθμούς ανάλογα με το είδος και το περιβάλ"
-			"λον του[3].",
-			"զարգացում",
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			"2010-10-04 08:42:57", stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "pas-id-4CA9939100000000",
+	                 "Στην επιστήμη της βιολογίας, με τον όρο εξέλιξη εννοείται η αλλαγή στις"
+	                 " ιδιότητες ενός πληθυσμού οργανισμών στο πέρασμα του χρόνου, μεταξύ δια"
+	                 "φορετικών γενεών[1]. Αν και τέτοιου τύπου μεταβολές παρατηρούνται σε μι"
+	                 "κρή κλίμακα σε κάθε γενιά, μακροπρόθεσμα και αθροιστικά μπορούν να οδηγ"
+	                 "ήσουν σε σημαντικές διαφοροποιήσεις στις ιδιότητες ενός οργανισμού, ώστ"
+	                 "ε να οδηγήσουν τελικά στη δημιουργία νέων διακριτών ειδών (βλ. ειδογένε"
+	                 "ση). Εξελικτικές θεωρούνται ειδικά οι αλλαγές που κληροδοτούνται μέσω τ"
+	                 "ου γενετικού υλικού από γενιά σε γενιά, συνεπώς συνιστούν μια πληθυσμικ"
+	                 "ή διαδικασία και διακρίνονται από άλλες, όπως η οντογένεση, ή γενικά η "
+	                 "ανάπτυξη ενός οργανισμού ατομικά. Η εξέλιξη αποτελεί φαινόμενο που υλοπ"
+	                 "οιείται σταδιακά και σε μεγάλο βάθος χρόνου. Με λίγες εξαιρέσεις[2], απ"
+	                 "αιτείται το πέρασμα αρκετών γενεών για εξελικτικές αλλαγές μεγάλης κλίμ"
+	                 "ακας, όπως για παράδειγμα η εξέλιξη των πτηνών από τα ερπετά. Λαμβάνει "
+	                 "επίσης χώρα με διαφορετικούς ρυθμούς ανάλογα με το είδος και το περιβάλ"
+	                 "λον του[3].",
+	                 "զարգացում",
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 "2010-10-04 08:42:57", stage);
 
 	/*
 	 * Name Fields
@@ -506,9 +500,9 @@ validate_evolution_contact_5 (const I_contact *icontact, gint stage)
 	 * Addresses
 	 */
 	assert_address_in_list(icontact->addresses, ICONTACT_ADDR_TYPE_HOME,
-			"ജീവികൾ സ്വയം പരിണമിച്ച് ലളിതഘടനയിൽ നിന്ന് സങ്കീർണഘടനയിലേക്കെത്തിച്ചേരുന്നു എന്ന് പരിണാമവാദം "
-			"സിധാന്തിക്കുന്നു. ചാൾസ് ഡാർവിൻ ആണ്‌ ഈ സിദ്ധാന്തത്തിന്റെ ഉപജ്ഞാതാവ്.",
-			"ശരിയാവണമെങ്കിൽ", "ജൈവപരിവർത്തനം", "ജീവികൾ", "", "ഭൂമിയിൽ");
+	                       "ജീവികൾ സ്വയം പരിണമിച്ച് ലളിതഘടനയിൽ നിന്ന് സങ്കീർണഘടനയിലേക്കെത്തിച്ചേരുന്നു എന്ന് പരിണാമവാദം "
+	                       "സിധാന്തിക്കുന്നു. ചാൾസ് ഡാർവിൻ ആണ്‌ ഈ സിദ്ധാന്തത്തിന്റെ ഉപജ്ഞാതാവ്.",
+	                       "ശരിയാവണമെങ്കിൽ", "ജൈവപരിവർത്തനം", "ജീവികൾ", "", "ഭൂമിയിൽ");
 	assert_list_length(icontact->addresses, 1);
 
 	/*
@@ -555,7 +549,7 @@ validate_evolution_contact_5 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:\r\nCALURI:\r\nX-MOZILLA-HTML:FALSE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 }
 
 
@@ -567,15 +561,14 @@ validate_evolution_contact_b1 (const I_contact *icontact, gint stage)
 	/*
 	 * Common Fields
 	 */
-	validate_icommon(
-			icontact->common,
-			NULL,
-			"20110330T111653Z-5957-1000-19106-0@christian-t60",
-			NULL,
-			NULL,
-			ICOMMON_SENSITIVITY_NULL,
-			NULL,
-			NULL, stage);
+	validate_icommon(icontact->common,
+	                 NULL,
+	                 "20110330T111653Z-5957-1000-19106-0@christian-t60",
+	                 NULL,
+	                 NULL,
+	                 ICOMMON_SENSITIVITY_NULL,
+	                 NULL,
+	                 NULL, stage);
 
 	/*
 	 * Name Fields
@@ -649,6 +642,6 @@ validate_evolution_contact_b1 (const I_contact *icontact, gint stage)
 	 */
 
 	assert_equal_gchar("BEGIN:VCARD\r\nVERSION:3.0\r\nX-EVOLUTION-VIDEO-URL:\r\nCALURI:\r\nX-MOZILLA-HTML:FALSE\r\nEND:VCARD",
-			icontact->common->evolution_store);
+	                   icontact->common->evolution_store);
 
 }
